/****************************************************************************
** Meta object code from reading C++ file 'searchsidebar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../zeal/src/libs/ui/searchsidebar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'searchsidebar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Zeal8WidgetUi13SearchSidebarE_t {};
} // unnamed namespace

template <> constexpr inline auto Zeal::WidgetUi::SearchSidebar::qt_create_metaobjectdata<qt_meta_tag_ZN4Zeal8WidgetUi13SearchSidebarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Zeal::WidgetUi::SearchSidebar",
        "activated",
        "",
        "navigationRequested",
        "QUrl",
        "url",
        "openInNewTabRequested",
        "activate",
        "focusSearchEdit",
        "clear",
        "search",
        "Registry::SearchQuery",
        "query",
        "navigateToIndex",
        "QModelIndex",
        "index",
        "navigateToIndexAndActivate",
        "navigateToSelectionWithDelay",
        "QItemSelection",
        "selection",
        "setupSearchBoxCompletions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigationRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'openInNewTabRequested'
        QtMocHelpers::SignalData<void(const QUrl &, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'openInNewTabRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'focusSearchEdit'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'focusSearchEdit'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'search'
        QtMocHelpers::SlotData<void(const Registry::SearchQuery &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'navigateToIndex'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'navigateToIndexAndActivate'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'navigateToSelectionWithDelay'
        QtMocHelpers::SlotData<void(const QItemSelection &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'setupSearchBoxCompletions'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SearchSidebar, qt_meta_tag_ZN4Zeal8WidgetUi13SearchSidebarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Zeal::WidgetUi::SearchSidebar::staticMetaObject = { {
    QMetaObject::SuperData::link<Sidebar::View::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Zeal8WidgetUi13SearchSidebarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Zeal8WidgetUi13SearchSidebarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Zeal8WidgetUi13SearchSidebarE_t>.metaTypes,
    nullptr
} };

void Zeal::WidgetUi::SearchSidebar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchSidebar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activated(); break;
        case 1: _t->navigationRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 2: _t->openInNewTabRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->openInNewTabRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->focusSearchEdit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->focusSearchEdit(); break;
        case 6: _t->search((*reinterpret_cast<std::add_pointer_t<Registry::SearchQuery>>(_a[1]))); break;
        case 7: _t->navigateToIndex((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->navigateToIndexAndActivate((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->navigateToSelectionWithDelay((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1]))); break;
        case 10: _t->setupSearchBoxCompletions(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SearchSidebar::*)()>(_a, &SearchSidebar::activated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchSidebar::*)(const QUrl & )>(_a, &SearchSidebar::navigationRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchSidebar::*)(const QUrl & , bool )>(_a, &SearchSidebar::openInNewTabRequested, 2))
            return;
    }
}

const QMetaObject *Zeal::WidgetUi::SearchSidebar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Zeal::WidgetUi::SearchSidebar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Zeal8WidgetUi13SearchSidebarE_t>.strings))
        return static_cast<void*>(this);
    return Sidebar::View::qt_metacast(_clname);
}

int Zeal::WidgetUi::SearchSidebar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Sidebar::View::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Zeal::WidgetUi::SearchSidebar::activated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Zeal::WidgetUi::SearchSidebar::navigationRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Zeal::WidgetUi::SearchSidebar::openInNewTabRequested(const QUrl & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
