/********************************************************************************
** Form generated from reading UI file 'aboutdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTDIALOG_H
#define UI_ABOUTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace Zeal {
namespace WidgetUi {

class Ui_AboutDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *nameLabel;
    QLabel *versionLabel;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_3;
    QLabel *label;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_4;
    QTextBrowser *textBrowser;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *Zeal__WidgetUi__AboutDialog)
    {
        if (Zeal__WidgetUi__AboutDialog->objectName().isEmpty())
            Zeal__WidgetUi__AboutDialog->setObjectName("Zeal__WidgetUi__AboutDialog");
        Zeal__WidgetUi__AboutDialog->resize(420, 420);
        verticalLayout = new QVBoxLayout(Zeal__WidgetUi__AboutDialog);
        verticalLayout->setObjectName("verticalLayout");
        frame = new QFrame(Zeal__WidgetUi__AboutDialog);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Sunken);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setSpacing(10);
        horizontalLayout->setObjectName("horizontalLayout");
        label_2 = new QLabel(frame);
        label_2->setObjectName("label_2");
        label_2->setPixmap(QPixmap(QString::fromUtf8(":/icons/logo/64x64.png")));

        horizontalLayout->addWidget(label_2);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        nameLabel = new QLabel(frame);
        nameLabel->setObjectName("nameLabel");

        verticalLayout_2->addWidget(nameLabel);

        versionLabel = new QLabel(frame);
        versionLabel->setObjectName("versionLabel");
        versionLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        verticalLayout_2->addWidget(versionLabel);


        horizontalLayout->addLayout(verticalLayout_2);

        horizontalLayout->setStretch(1, 1);

        verticalLayout->addWidget(frame);

        tabWidget = new QTabWidget(Zeal__WidgetUi__AboutDialog);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_3 = new QVBoxLayout(tab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label = new QLabel(tab);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label->setWordWrap(true);
        label->setOpenExternalLinks(true);

        verticalLayout_3->addWidget(label);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_4 = new QVBoxLayout(tab_2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        textBrowser = new QTextBrowser(tab_2);
        textBrowser->setObjectName("textBrowser");
        textBrowser->setOpenExternalLinks(true);

        verticalLayout_4->addWidget(textBrowser);

        tabWidget->addTab(tab_2, QString());

        verticalLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(Zeal__WidgetUi__AboutDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(Zeal__WidgetUi__AboutDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::clicked, Zeal__WidgetUi__AboutDialog, qOverload<>(&QDialog::close));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Zeal__WidgetUi__AboutDialog);
    } // setupUi

    void retranslateUi(QDialog *Zeal__WidgetUi__AboutDialog)
    {
        Zeal__WidgetUi__AboutDialog->setWindowTitle(QCoreApplication::translate("Zeal::WidgetUi::AboutDialog", "About Zeal", nullptr));
        label_2->setText(QString());
        nameLabel->setText(QCoreApplication::translate("Zeal::WidgetUi::AboutDialog", "<h1>Zeal</h1>", nullptr));
        versionLabel->setText(QString());
        label->setText(QCoreApplication::translate("Zeal::WidgetUi::AboutDialog", "<strong>A simple offline documentation browser</strong>\n"
"<br><br>\n"
"Copyright &copy; Oleg Shparber and other contributors, 2013-2026.\n"
"<br>\n"
"<a href=\"https://zealdocs.org\">zealdocs.org</a>\n"
"<br>\n"
"<a href=\"ircs://irc.libera.chat:6697/zealdocs\">#zealdocs</a> on <a href=\"https://libera.chat\">Libera Chat</a>\n"
"<br><br>\n"
"Zeal is an open source software available under the terms of the General Public License version 3 (<a href=\"https://www.gnu.org/copyleft/gpl.html\">GPLv3</a>) or later.\n"
"<br><br>\n"
"Docsets are courtesy of <a href=\"https://kapeli.com/dash\">Dash</a>.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("Zeal::WidgetUi::AboutDialog", "About", nullptr));
        textBrowser->setHtml(QCoreApplication::translate("Zeal::WidgetUi::AboutDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Roboto'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\">Zeal heavily relies on other open source software listed below.</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:600;\">cpp-httplib</span><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"> - </span><a href=\"https://github.com/yhirose/cpp-httplib\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; text-decorat"
                        "ion: underline; color:#007af4;\">github.com/yhirose/cpp-httplib</span></a><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"><br />License: MIT License</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:600;\">libarchive</span><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"> - </span><a href=\"https://www.libarchive.org/\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; text-decoration: underline; color:#007af4;\">www.libarchive.org</span></a><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"><br />License: Simplified BSD License</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:600;\">LibQxt</span><span style=\" font-family:'MS She"
                        "ll Dlg 2'; font-size:8.25pt;\"> - </span><a href=\"https://bitbucket.org/libqxt/libqxt\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; text-decoration: underline; color:#007af4;\">bitbucket.org/libqxt/libqxt</span></a><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"><br />License: New BSD License</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:600;\">Lucide</span><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"> - </span><a href=\"https://lucide.dev/\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; text-decoration: underline; color:#007af4;\">lucide.dev</span></a><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"><br />License: ISC License</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0p"
                        "x;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:600;\">Oat</span><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"> - </span><a href=\"https://oat.ink/\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; text-decoration: underline; color:#007af4;\">oat.ink</span></a><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"><br />License: MIT License</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:600;\">Qt</span><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"> - </span><a href=\"https://www.qt.io/\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; text-decoration: underline; color:#007af4;\">www.qt.io</span></a><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"><br />License: GNU LGPL version 3</span></p>\n"
"<p style=\" margin-top:12px; "
                        "margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:600;\">Simple Icons</span><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"> - </span><a href=\"https://simpleicons.org/\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; text-decoration: underline; color:#007af4;\">simpleicons.org</span></a><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"><br />License: CC0 1.0 Universal</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:600;\">SQLite</span><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"> - </span><a href=\"https://www.sqlite.org/\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; text-decoration: underline; color:#007af4;\">www.sqlite.org</span></a><span sty"
                        "le=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt;\"><br />License: Public Domain</span></p></body></html>", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("Zeal::WidgetUi::AboutDialog", "Licenses", nullptr));
    } // retranslateUi

};

} // namespace WidgetUi
} // namespace Zeal

namespace Zeal {
namespace WidgetUi {
namespace Ui {
    class AboutDialog: public Ui_AboutDialog {};
} // namespace Ui
} // namespace WidgetUi
} // namespace Zeal

#endif // UI_ABOUTDIALOG_H
