/********************************************************************************
** Form generated from reading UI file 'settingsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSDIALOG_H
#define UI_SETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "ui/settingsdialog.h"
#include "ui/widgets/shortcutedit.h"

namespace Zeal {
namespace WidgetUi {

class Ui_SettingsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *generalTab;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_9;
    QCheckBox *startMinimizedCheckBox;
    QCheckBox *checkForUpdateCheckBox;
    QGroupBox *systrayGroupBox;
    QVBoxLayout *verticalLayout_8;
    QCheckBox *minimizeToSystrayCheckBox;
    QCheckBox *hideToSystrayCheckBox;
    QGroupBox *globalHotKeyGroupBox;
    QFormLayout *formLayout_2;
    QLabel *label_9;
    ShortcutEdit *toolButton;
    QGroupBox *groupBox_4;
    QFormLayout *formLayout_3;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *docsetStorageEdit;
    QPushButton *docsetStorageBrowseButton;
    QSpacerItem *verticalSpacer;
    QWidget *tabsTab;
    QVBoxLayout *verticalLayout_6;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout_12;
    QCheckBox *openNewTabAfterActive;
    QSpacerItem *verticalSpacer_5;
    QWidget *searchTab;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupBox_5;
    QVBoxLayout *verticalLayout_11;
    QCheckBox *fuzzySearchCheckBox;
    QSpacerItem *verticalSpacer_4;
    QWidget *contentTab;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *styleGroupBox;
    QVBoxLayout *verticalLayout_17;
    QHBoxLayout *horizontalLayout_4;
    QLabel *appearanceLabel;
    QRadioButton *appearanceAutoRadioButton;
    QRadioButton *appearanceLightRadioButton;
    QRadioButton *appearanceDarkRadioButton;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout;
    QLabel *customCssFileLabel;
    QLineEdit *customCssFileEdit;
    QPushButton *customCssFileBrowseButton;
    QCheckBox *highlightOnNavigateCheckBox;
    QGroupBox *fontsGroupBox;
    QVBoxLayout *verticalLayout_14;
    QHBoxLayout *horizontalLayout_3;
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *defaultFontComboBox;
    QLabel *label_4;
    QFontComboBox *serifFontComboBox;
    QLabel *label_6;
    QFontComboBox *sansSerifFontComboBox;
    QLabel *label_3;
    QFontComboBox *fixedFontComboBox;
    QVBoxLayout *verticalLayout_16;
    QFormLayout *formLayout_6;
    QLabel *label_7;
    QComboBox *fontSizeComboBox;
    QSpacerItem *verticalSpacer_6;
    QFormLayout *formLayout_4;
    QLabel *label_11;
    QComboBox *fixedFontSizeComboBox;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_2;
    QComboBox *minFontSizeComboBox;
    QGroupBox *groupBox_7;
    QVBoxLayout *verticalLayout_13;
    QRadioButton *radioExternalLinkAsk;
    QRadioButton *radioExternalLinkOpenDesktop;
    QRadioButton *radioExternalLinkOpen;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *useSmoothScrollingCheckBox;
    QSpacerItem *verticalSpacer_3;
    QWidget *networkTab;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_10;
    QRadioButton *noProxySettings;
    QRadioButton *systemProxySettings;
    QRadioButton *manualProxySettings;
    QWidget *manualProxySettingsGroup;
    QFormLayout *manualProxyConfigurationLayout;
    QLabel *proxyHostLabel;
    QLabel *proxyTypeLabel;
    QHBoxLayout *proxyTypeLayout;
    QRadioButton *proxyTypeHttpRadioButton;
    QRadioButton *proxyTypeSocks5RadioButton;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *proxyHostPortLayout;
    QLineEdit *proxyHostEdit;
    QLabel *proxyPortLabel;
    QSpinBox *proxyPortEdit;
    QCheckBox *proxyRequiresAuthCheckBox;
    QLabel *proxyUsernameLabel;
    QLabel *proxyPasswordLabel;
    QLineEdit *proxyUsernameEdit;
    QLineEdit *proxyPasswordEdit;
    QGroupBox *groupBox_8;
    QVBoxLayout *verticalLayout_15;
    QCheckBox *ignoreSslErrorsCheckBox;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *buttonBox;
    QButtonGroup *proxyTypeButtonGroup;

    void setupUi(SettingsDialog *Zeal__WidgetUi__SettingsDialog)
    {
        if (Zeal__WidgetUi__SettingsDialog->objectName().isEmpty())
            Zeal__WidgetUi__SettingsDialog->setObjectName("Zeal__WidgetUi__SettingsDialog");
        Zeal__WidgetUi__SettingsDialog->setWindowModality(Qt::ApplicationModal);
        Zeal__WidgetUi__SettingsDialog->resize(600, 700);
        verticalLayout = new QVBoxLayout(Zeal__WidgetUi__SettingsDialog);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(Zeal__WidgetUi__SettingsDialog);
        tabWidget->setObjectName("tabWidget");
        generalTab = new QWidget();
        generalTab->setObjectName("generalTab");
        verticalLayout_7 = new QVBoxLayout(generalTab);
        verticalLayout_7->setObjectName("verticalLayout_7");
        groupBox_3 = new QGroupBox(generalTab);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_9 = new QVBoxLayout(groupBox_3);
        verticalLayout_9->setObjectName("verticalLayout_9");
        startMinimizedCheckBox = new QCheckBox(groupBox_3);
        startMinimizedCheckBox->setObjectName("startMinimizedCheckBox");

        verticalLayout_9->addWidget(startMinimizedCheckBox);

        checkForUpdateCheckBox = new QCheckBox(groupBox_3);
        checkForUpdateCheckBox->setObjectName("checkForUpdateCheckBox");
        checkForUpdateCheckBox->setChecked(true);

        verticalLayout_9->addWidget(checkForUpdateCheckBox);


        verticalLayout_7->addWidget(groupBox_3);

        systrayGroupBox = new QGroupBox(generalTab);
        systrayGroupBox->setObjectName("systrayGroupBox");
        systrayGroupBox->setCheckable(true);
        verticalLayout_8 = new QVBoxLayout(systrayGroupBox);
        verticalLayout_8->setObjectName("verticalLayout_8");
        minimizeToSystrayCheckBox = new QCheckBox(systrayGroupBox);
        minimizeToSystrayCheckBox->setObjectName("minimizeToSystrayCheckBox");

        verticalLayout_8->addWidget(minimizeToSystrayCheckBox);

        hideToSystrayCheckBox = new QCheckBox(systrayGroupBox);
        hideToSystrayCheckBox->setObjectName("hideToSystrayCheckBox");

        verticalLayout_8->addWidget(hideToSystrayCheckBox);


        verticalLayout_7->addWidget(systrayGroupBox);

        globalHotKeyGroupBox = new QGroupBox(generalTab);
        globalHotKeyGroupBox->setObjectName("globalHotKeyGroupBox");
        formLayout_2 = new QFormLayout(globalHotKeyGroupBox);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_9 = new QLabel(globalHotKeyGroupBox);
        label_9->setObjectName("label_9");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_9);

        toolButton = new ShortcutEdit(globalHotKeyGroupBox);
        toolButton->setObjectName("toolButton");
        toolButton->setClearButtonEnabled(true);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, toolButton);


        verticalLayout_7->addWidget(globalHotKeyGroupBox);

        groupBox_4 = new QGroupBox(generalTab);
        groupBox_4->setObjectName("groupBox_4");
        formLayout_3 = new QFormLayout(groupBox_4);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_5 = new QLabel(groupBox_4);
        label_5->setObjectName("label_5");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        docsetStorageEdit = new QLineEdit(groupBox_4);
        docsetStorageEdit->setObjectName("docsetStorageEdit");
        docsetStorageEdit->setClearButtonEnabled(true);

        horizontalLayout_2->addWidget(docsetStorageEdit);

        docsetStorageBrowseButton = new QPushButton(groupBox_4);
        docsetStorageBrowseButton->setObjectName("docsetStorageBrowseButton");

        horizontalLayout_2->addWidget(docsetStorageBrowseButton);


        formLayout_3->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);


        verticalLayout_7->addWidget(groupBox_4);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_7->addItem(verticalSpacer);

        tabWidget->addTab(generalTab, QString());
        tabsTab = new QWidget();
        tabsTab->setObjectName("tabsTab");
        verticalLayout_6 = new QVBoxLayout(tabsTab);
        verticalLayout_6->setObjectName("verticalLayout_6");
        groupBox_6 = new QGroupBox(tabsTab);
        groupBox_6->setObjectName("groupBox_6");
        verticalLayout_12 = new QVBoxLayout(groupBox_6);
        verticalLayout_12->setObjectName("verticalLayout_12");
        openNewTabAfterActive = new QCheckBox(groupBox_6);
        openNewTabAfterActive->setObjectName("openNewTabAfterActive");

        verticalLayout_12->addWidget(openNewTabAfterActive);


        verticalLayout_6->addWidget(groupBox_6);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_5);

        tabWidget->addTab(tabsTab, QString());
        searchTab = new QWidget();
        searchTab->setObjectName("searchTab");
        verticalLayout_4 = new QVBoxLayout(searchTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        groupBox_5 = new QGroupBox(searchTab);
        groupBox_5->setObjectName("groupBox_5");
        verticalLayout_11 = new QVBoxLayout(groupBox_5);
        verticalLayout_11->setObjectName("verticalLayout_11");
        fuzzySearchCheckBox = new QCheckBox(groupBox_5);
        fuzzySearchCheckBox->setObjectName("fuzzySearchCheckBox");

        verticalLayout_11->addWidget(fuzzySearchCheckBox);


        verticalLayout_4->addWidget(groupBox_5);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_4);

        tabWidget->addTab(searchTab, QString());
        contentTab = new QWidget();
        contentTab->setObjectName("contentTab");
        verticalLayout_3 = new QVBoxLayout(contentTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        styleGroupBox = new QGroupBox(contentTab);
        styleGroupBox->setObjectName("styleGroupBox");
        verticalLayout_17 = new QVBoxLayout(styleGroupBox);
        verticalLayout_17->setObjectName("verticalLayout_17");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        appearanceLabel = new QLabel(styleGroupBox);
        appearanceLabel->setObjectName("appearanceLabel");

        horizontalLayout_4->addWidget(appearanceLabel);

        appearanceAutoRadioButton = new QRadioButton(styleGroupBox);
        appearanceAutoRadioButton->setObjectName("appearanceAutoRadioButton");
        appearanceAutoRadioButton->setChecked(true);

        horizontalLayout_4->addWidget(appearanceAutoRadioButton);

        appearanceLightRadioButton = new QRadioButton(styleGroupBox);
        appearanceLightRadioButton->setObjectName("appearanceLightRadioButton");

        horizontalLayout_4->addWidget(appearanceLightRadioButton);

        appearanceDarkRadioButton = new QRadioButton(styleGroupBox);
        appearanceDarkRadioButton->setObjectName("appearanceDarkRadioButton");

        horizontalLayout_4->addWidget(appearanceDarkRadioButton);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);


        verticalLayout_17->addLayout(horizontalLayout_4);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        customCssFileLabel = new QLabel(styleGroupBox);
        customCssFileLabel->setObjectName("customCssFileLabel");

        horizontalLayout->addWidget(customCssFileLabel);

        customCssFileEdit = new QLineEdit(styleGroupBox);
        customCssFileEdit->setObjectName("customCssFileEdit");
        customCssFileEdit->setClearButtonEnabled(true);

        horizontalLayout->addWidget(customCssFileEdit);

        customCssFileBrowseButton = new QPushButton(styleGroupBox);
        customCssFileBrowseButton->setObjectName("customCssFileBrowseButton");

        horizontalLayout->addWidget(customCssFileBrowseButton);


        verticalLayout_17->addLayout(horizontalLayout);

        highlightOnNavigateCheckBox = new QCheckBox(styleGroupBox);
        highlightOnNavigateCheckBox->setObjectName("highlightOnNavigateCheckBox");

        verticalLayout_17->addWidget(highlightOnNavigateCheckBox);


        verticalLayout_3->addWidget(styleGroupBox);

        fontsGroupBox = new QGroupBox(contentTab);
        fontsGroupBox->setObjectName("fontsGroupBox");
        verticalLayout_14 = new QVBoxLayout(fontsGroupBox);
        verticalLayout_14->setObjectName("verticalLayout_14");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setSizeConstraint(QLayout::SetMinimumSize);
        label = new QLabel(fontsGroupBox);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        defaultFontComboBox = new QComboBox(fontsGroupBox);
        defaultFontComboBox->setObjectName("defaultFontComboBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, defaultFontComboBox);

        label_4 = new QLabel(fontsGroupBox);
        label_4->setObjectName("label_4");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_4);

        serifFontComboBox = new QFontComboBox(fontsGroupBox);
        serifFontComboBox->setObjectName("serifFontComboBox");
        serifFontComboBox->setFontFilters(QFontComboBox::ScalableFonts);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, serifFontComboBox);

        label_6 = new QLabel(fontsGroupBox);
        label_6->setObjectName("label_6");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_6);

        sansSerifFontComboBox = new QFontComboBox(fontsGroupBox);
        sansSerifFontComboBox->setObjectName("sansSerifFontComboBox");
        sansSerifFontComboBox->setFontFilters(QFontComboBox::ScalableFonts);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, sansSerifFontComboBox);

        label_3 = new QLabel(fontsGroupBox);
        label_3->setObjectName("label_3");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        fixedFontComboBox = new QFontComboBox(fontsGroupBox);
        fixedFontComboBox->setObjectName("fixedFontComboBox");
        fixedFontComboBox->setFontFilters(QFontComboBox::MonospacedFonts|QFontComboBox::ScalableFonts);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, fixedFontComboBox);


        horizontalLayout_3->addLayout(formLayout);

        verticalLayout_16 = new QVBoxLayout();
        verticalLayout_16->setObjectName("verticalLayout_16");
        formLayout_6 = new QFormLayout();
        formLayout_6->setObjectName("formLayout_6");
        label_7 = new QLabel(fontsGroupBox);
        label_7->setObjectName("label_7");

        formLayout_6->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        fontSizeComboBox = new QComboBox(fontsGroupBox);
        fontSizeComboBox->setObjectName("fontSizeComboBox");

        formLayout_6->setWidget(0, QFormLayout::ItemRole::FieldRole, fontSizeComboBox);


        verticalLayout_16->addLayout(formLayout_6);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_16->addItem(verticalSpacer_6);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        label_11 = new QLabel(fontsGroupBox);
        label_11->setObjectName("label_11");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_11);

        fixedFontSizeComboBox = new QComboBox(fontsGroupBox);
        fixedFontSizeComboBox->setObjectName("fixedFontSizeComboBox");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, fixedFontSizeComboBox);


        verticalLayout_16->addLayout(formLayout_4);


        horizontalLayout_3->addLayout(verticalLayout_16);

        horizontalLayout_3->setStretch(0, 4);

        verticalLayout_14->addLayout(horizontalLayout_3);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);

        label_2 = new QLabel(fontsGroupBox);
        label_2->setObjectName("label_2");

        horizontalLayout_5->addWidget(label_2);

        minFontSizeComboBox = new QComboBox(fontsGroupBox);
        minFontSizeComboBox->setObjectName("minFontSizeComboBox");

        horizontalLayout_5->addWidget(minFontSizeComboBox);


        verticalLayout_14->addLayout(horizontalLayout_5);


        verticalLayout_3->addWidget(fontsGroupBox);

        groupBox_7 = new QGroupBox(contentTab);
        groupBox_7->setObjectName("groupBox_7");
        verticalLayout_13 = new QVBoxLayout(groupBox_7);
        verticalLayout_13->setObjectName("verticalLayout_13");
        radioExternalLinkAsk = new QRadioButton(groupBox_7);
        radioExternalLinkAsk->setObjectName("radioExternalLinkAsk");
        radioExternalLinkAsk->setChecked(true);

        verticalLayout_13->addWidget(radioExternalLinkAsk);

        radioExternalLinkOpenDesktop = new QRadioButton(groupBox_7);
        radioExternalLinkOpenDesktop->setObjectName("radioExternalLinkOpenDesktop");

        verticalLayout_13->addWidget(radioExternalLinkOpenDesktop);

        radioExternalLinkOpen = new QRadioButton(groupBox_7);
        radioExternalLinkOpen->setObjectName("radioExternalLinkOpen");

        verticalLayout_13->addWidget(radioExternalLinkOpen);


        verticalLayout_3->addWidget(groupBox_7);

        groupBox_2 = new QGroupBox(contentTab);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_5 = new QVBoxLayout(groupBox_2);
        verticalLayout_5->setObjectName("verticalLayout_5");
        useSmoothScrollingCheckBox = new QCheckBox(groupBox_2);
        useSmoothScrollingCheckBox->setObjectName("useSmoothScrollingCheckBox");

        verticalLayout_5->addWidget(useSmoothScrollingCheckBox);


        verticalLayout_3->addWidget(groupBox_2);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        tabWidget->addTab(contentTab, QString());
        networkTab = new QWidget();
        networkTab->setObjectName("networkTab");
        verticalLayout_2 = new QVBoxLayout(networkTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(networkTab);
        groupBox->setObjectName("groupBox");
        verticalLayout_10 = new QVBoxLayout(groupBox);
        verticalLayout_10->setObjectName("verticalLayout_10");
        noProxySettings = new QRadioButton(groupBox);
        noProxySettings->setObjectName("noProxySettings");
        noProxySettings->setChecked(false);

        verticalLayout_10->addWidget(noProxySettings);

        systemProxySettings = new QRadioButton(groupBox);
        systemProxySettings->setObjectName("systemProxySettings");
        systemProxySettings->setEnabled(true);
        systemProxySettings->setChecked(true);

        verticalLayout_10->addWidget(systemProxySettings);

        manualProxySettings = new QRadioButton(groupBox);
        manualProxySettings->setObjectName("manualProxySettings");

        verticalLayout_10->addWidget(manualProxySettings);

        manualProxySettingsGroup = new QWidget(groupBox);
        manualProxySettingsGroup->setObjectName("manualProxySettingsGroup");
        manualProxySettingsGroup->setEnabled(false);
        manualProxyConfigurationLayout = new QFormLayout(manualProxySettingsGroup);
        manualProxyConfigurationLayout->setObjectName("manualProxyConfigurationLayout");
        proxyHostLabel = new QLabel(manualProxySettingsGroup);
        proxyHostLabel->setObjectName("proxyHostLabel");

        manualProxyConfigurationLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, proxyHostLabel);

        proxyTypeLabel = new QLabel(manualProxySettingsGroup);
        proxyTypeLabel->setObjectName("proxyTypeLabel");

        manualProxyConfigurationLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, proxyTypeLabel);

        proxyTypeLayout = new QHBoxLayout();
        proxyTypeLayout->setObjectName("proxyTypeLayout");
        proxyTypeHttpRadioButton = new QRadioButton(manualProxySettingsGroup);
        proxyTypeButtonGroup = new QButtonGroup(Zeal__WidgetUi__SettingsDialog);
        proxyTypeButtonGroup->setObjectName("proxyTypeButtonGroup");
        proxyTypeButtonGroup->addButton(proxyTypeHttpRadioButton);
        proxyTypeHttpRadioButton->setObjectName("proxyTypeHttpRadioButton");
        proxyTypeHttpRadioButton->setChecked(true);

        proxyTypeLayout->addWidget(proxyTypeHttpRadioButton);

        proxyTypeSocks5RadioButton = new QRadioButton(manualProxySettingsGroup);
        proxyTypeButtonGroup->addButton(proxyTypeSocks5RadioButton);
        proxyTypeSocks5RadioButton->setObjectName("proxyTypeSocks5RadioButton");

        proxyTypeLayout->addWidget(proxyTypeSocks5RadioButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        proxyTypeLayout->addItem(horizontalSpacer);


        manualProxyConfigurationLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, proxyTypeLayout);

        proxyHostPortLayout = new QHBoxLayout();
        proxyHostPortLayout->setObjectName("proxyHostPortLayout");
        proxyHostEdit = new QLineEdit(manualProxySettingsGroup);
        proxyHostEdit->setObjectName("proxyHostEdit");

        proxyHostPortLayout->addWidget(proxyHostEdit);

        proxyPortLabel = new QLabel(manualProxySettingsGroup);
        proxyPortLabel->setObjectName("proxyPortLabel");

        proxyHostPortLayout->addWidget(proxyPortLabel);

        proxyPortEdit = new QSpinBox(manualProxySettingsGroup);
        proxyPortEdit->setObjectName("proxyPortEdit");
        proxyPortEdit->setMaximum(65535);

        proxyHostPortLayout->addWidget(proxyPortEdit);


        manualProxyConfigurationLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, proxyHostPortLayout);

        proxyRequiresAuthCheckBox = new QCheckBox(manualProxySettingsGroup);
        proxyRequiresAuthCheckBox->setObjectName("proxyRequiresAuthCheckBox");

        manualProxyConfigurationLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, proxyRequiresAuthCheckBox);

        proxyUsernameLabel = new QLabel(manualProxySettingsGroup);
        proxyUsernameLabel->setObjectName("proxyUsernameLabel");
        proxyUsernameLabel->setEnabled(false);

        manualProxyConfigurationLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, proxyUsernameLabel);

        proxyPasswordLabel = new QLabel(manualProxySettingsGroup);
        proxyPasswordLabel->setObjectName("proxyPasswordLabel");
        proxyPasswordLabel->setEnabled(false);

        manualProxyConfigurationLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, proxyPasswordLabel);

        proxyUsernameEdit = new QLineEdit(manualProxySettingsGroup);
        proxyUsernameEdit->setObjectName("proxyUsernameEdit");
        proxyUsernameEdit->setEnabled(false);

        manualProxyConfigurationLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, proxyUsernameEdit);

        proxyPasswordEdit = new QLineEdit(manualProxySettingsGroup);
        proxyPasswordEdit->setObjectName("proxyPasswordEdit");
        proxyPasswordEdit->setEnabled(false);
        proxyPasswordEdit->setEchoMode(QLineEdit::Password);

        manualProxyConfigurationLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, proxyPasswordEdit);


        verticalLayout_10->addWidget(manualProxySettingsGroup);


        verticalLayout_2->addWidget(groupBox);

        groupBox_8 = new QGroupBox(networkTab);
        groupBox_8->setObjectName("groupBox_8");
        verticalLayout_15 = new QVBoxLayout(groupBox_8);
        verticalLayout_15->setObjectName("verticalLayout_15");
        ignoreSslErrorsCheckBox = new QCheckBox(groupBox_8);
        ignoreSslErrorsCheckBox->setObjectName("ignoreSslErrorsCheckBox");

        verticalLayout_15->addWidget(ignoreSslErrorsCheckBox);


        verticalLayout_2->addWidget(groupBox_8);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(networkTab, QString());

        verticalLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(Zeal__WidgetUi__SettingsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label_5->setBuddy(docsetStorageEdit);
        customCssFileLabel->setBuddy(customCssFileEdit);
        label->setBuddy(defaultFontComboBox);
        label_4->setBuddy(serifFontComboBox);
        label_6->setBuddy(sansSerifFontComboBox);
        label_3->setBuddy(fixedFontComboBox);
        label_7->setBuddy(fontSizeComboBox);
        label_11->setBuddy(fixedFontSizeComboBox);
        label_2->setBuddy(minFontSizeComboBox);
        proxyHostLabel->setBuddy(proxyHostEdit);
        proxyPortLabel->setBuddy(proxyPortEdit);
        proxyUsernameLabel->setBuddy(proxyUsernameEdit);
        proxyPasswordLabel->setBuddy(proxyPasswordEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(Zeal__WidgetUi__SettingsDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, Zeal__WidgetUi__SettingsDialog, qOverload<>(&SettingsDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, Zeal__WidgetUi__SettingsDialog, qOverload<>(&SettingsDialog::reject));
        QObject::connect(customCssFileBrowseButton, &QPushButton::clicked, Zeal__WidgetUi__SettingsDialog, qOverload<>(&SettingsDialog::chooseCustomCssFile));
        QObject::connect(docsetStorageBrowseButton, &QPushButton::clicked, Zeal__WidgetUi__SettingsDialog, qOverload<>(&SettingsDialog::chooseDocsetStoragePath));
        QObject::connect(manualProxySettings, &QRadioButton::toggled, manualProxySettingsGroup, &QWidget::setEnabled);
        QObject::connect(proxyRequiresAuthCheckBox, &QCheckBox::toggled, proxyUsernameLabel, &QLabel::setEnabled);
        QObject::connect(proxyRequiresAuthCheckBox, &QCheckBox::toggled, proxyUsernameEdit, &QLineEdit::setEnabled);
        QObject::connect(proxyRequiresAuthCheckBox, &QCheckBox::toggled, proxyPasswordLabel, &QLabel::setEnabled);
        QObject::connect(proxyRequiresAuthCheckBox, &QCheckBox::toggled, proxyPasswordEdit, &QLineEdit::setEnabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Zeal__WidgetUi__SettingsDialog);
    } // setupUi

    void retranslateUi(SettingsDialog *Zeal__WidgetUi__SettingsDialog)
    {
        Zeal__WidgetUi__SettingsDialog->setWindowTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Preferences", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Startup", nullptr));
        startMinimizedCheckBox->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Start minimized", nullptr));
        checkForUpdateCheckBox->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Check for update", nullptr));
        systrayGroupBox->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Show system tray icon", nullptr));
        minimizeToSystrayCheckBox->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Minimize to system tray instead of taskbar", nullptr));
        hideToSystrayCheckBox->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Hide to system tray on window close", nullptr));
        globalHotKeyGroupBox->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Global shortcuts", nullptr));
        label_9->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Show Zeal:", nullptr));
        toolButton->setPlaceholderText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Click to set shortcut", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Docset storage", nullptr));
        label_5->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Directory:", nullptr));
        docsetStorageBrowseButton->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Browse\342\200\246", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(generalTab), QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "General", nullptr));
        groupBox_6->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Behavior", nullptr));
        openNewTabAfterActive->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Open new tab after active", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabsTab), QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Tabs", nullptr));
        groupBox_5->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Local search", nullptr));
        fuzzySearchCheckBox->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Use fuzzy search (experimental)", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(searchTab), QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Search", nullptr));
        styleGroupBox->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Style", nullptr));
        appearanceLabel->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Appearance:", nullptr));
        appearanceAutoRadioButton->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "A&utomatic", nullptr));
        appearanceLightRadioButton->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Light", nullptr));
        appearanceDarkRadioButton->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Dark", nullptr));
        customCssFileLabel->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Custom CSS file:", nullptr));
        customCssFileBrowseButton->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Bro&wse\342\200\246", nullptr));
        highlightOnNavigateCheckBox->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Highlight on navigate", nullptr));
        fontsGroupBox->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Fonts", nullptr));
        label->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "De&fault:", nullptr));
        label_4->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Serif:", nullptr));
        label_6->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Sa&ns-serif:", nullptr));
        label_3->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Monospace:", nullptr));
        label_7->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Si&ze:", nullptr));
        label_11->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Siz&e:", nullptr));
        label_2->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Minimum f&ont size:", nullptr));
        groupBox_7->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "External Link Behavior", nullptr));
        radioExternalLinkAsk->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Ask every time", nullptr));
        radioExternalLinkOpenDesktop->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Open in desktop &browser", nullptr));
        radioExternalLinkOpen->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "O&pen in Zeal", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Other", nullptr));
        useSmoothScrollingCheckBox->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Use smoo&th scrolling", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(contentTab), QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Content", nullptr));
        groupBox->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Proxy Settings", nullptr));
        noProxySettings->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "No prox&y", nullptr));
        systemProxySettings->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Use system proxy settings", nullptr));
        manualProxySettings->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Manual proxy configuration", nullptr));
        proxyHostLabel->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Pro&xy host:", nullptr));
        proxyTypeLabel->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Type:", nullptr));
        proxyTypeHttpRadioButton->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&HTTP", nullptr));
        proxyTypeSocks5RadioButton->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&SOCKS5", nullptr));
        proxyPortLabel->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Port:", nullptr));
        proxyRequiresAuthCheckBox->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "&Authentication required", nullptr));
        proxyUsernameLabel->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "User&name:", nullptr));
        proxyPasswordLabel->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Pass&word:", nullptr));
        groupBox_8->setTitle(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Security", nullptr));
        ignoreSslErrorsCheckBox->setText(QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Ignore SSL errors", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(networkTab), QCoreApplication::translate("Zeal::WidgetUi::SettingsDialog", "Network", nullptr));
    } // retranslateUi

};

} // namespace WidgetUi
} // namespace Zeal

namespace Zeal {
namespace WidgetUi {
namespace Ui {
    class SettingsDialog: public Ui_SettingsDialog {};
} // namespace Ui
} // namespace WidgetUi
} // namespace Zeal

#endif // UI_SETTINGSDIALOG_H
