/********************************************************************************
** Form generated from reading UI file 'docsetsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOCSETSDIALOG_H
#define UI_DOCSETSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace Zeal {
namespace WidgetUi {

class Ui_DocsetsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *installedDocsetsTab;
    QVBoxLayout *verticalLayout_5;
    QTreeView *installedDocsetList;
    QHBoxLayout *docsetsActions;
    QPushButton *addFeedButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *updateSelectedDocsetsButton;
    QPushButton *updateAllDocsetsButton;
    QPushButton *removeDocsetsButton;
    QWidget *availableDocsetsTab;
    QVBoxLayout *verticalLayout_2;
    QLineEdit *docsetFilterInput;
    QListWidget *availableDocsetList;
    QHBoxLayout *horizontalLayout;
    QLabel *lastUpdatedLabel;
    QPushButton *refreshButton;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *downloadDocsetsButton;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_2;
    QLabel *statusLabel;
    QSpacerItem *horizontalSpacer_3;
    QLabel *storageStatusLabel;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *Zeal__WidgetUi__DocsetsDialog)
    {
        if (Zeal__WidgetUi__DocsetsDialog->objectName().isEmpty())
            Zeal__WidgetUi__DocsetsDialog->setObjectName("Zeal__WidgetUi__DocsetsDialog");
        Zeal__WidgetUi__DocsetsDialog->setWindowModality(Qt::ApplicationModal);
        Zeal__WidgetUi__DocsetsDialog->resize(600, 500);
        verticalLayout = new QVBoxLayout(Zeal__WidgetUi__DocsetsDialog);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(Zeal__WidgetUi__DocsetsDialog);
        tabWidget->setObjectName("tabWidget");
        installedDocsetsTab = new QWidget();
        installedDocsetsTab->setObjectName("installedDocsetsTab");
        verticalLayout_5 = new QVBoxLayout(installedDocsetsTab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        installedDocsetList = new QTreeView(installedDocsetsTab);
        installedDocsetList->setObjectName("installedDocsetList");
        installedDocsetList->setSelectionMode(QAbstractItemView::ExtendedSelection);
        installedDocsetList->setSelectionBehavior(QAbstractItemView::SelectRows);
        installedDocsetList->setIconSize(QSize(16, 16));

        verticalLayout_5->addWidget(installedDocsetList);

        docsetsActions = new QHBoxLayout();
        docsetsActions->setObjectName("docsetsActions");
        addFeedButton = new QPushButton(installedDocsetsTab);
        addFeedButton->setObjectName("addFeedButton");

        docsetsActions->addWidget(addFeedButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        docsetsActions->addItem(horizontalSpacer);

        updateSelectedDocsetsButton = new QPushButton(installedDocsetsTab);
        updateSelectedDocsetsButton->setObjectName("updateSelectedDocsetsButton");
        updateSelectedDocsetsButton->setEnabled(false);

        docsetsActions->addWidget(updateSelectedDocsetsButton);

        updateAllDocsetsButton = new QPushButton(installedDocsetsTab);
        updateAllDocsetsButton->setObjectName("updateAllDocsetsButton");
        updateAllDocsetsButton->setEnabled(false);

        docsetsActions->addWidget(updateAllDocsetsButton);

        removeDocsetsButton = new QPushButton(installedDocsetsTab);
        removeDocsetsButton->setObjectName("removeDocsetsButton");
        removeDocsetsButton->setEnabled(false);

        docsetsActions->addWidget(removeDocsetsButton);


        verticalLayout_5->addLayout(docsetsActions);

        tabWidget->addTab(installedDocsetsTab, QString());
        availableDocsetsTab = new QWidget();
        availableDocsetsTab->setObjectName("availableDocsetsTab");
        verticalLayout_2 = new QVBoxLayout(availableDocsetsTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        docsetFilterInput = new QLineEdit(availableDocsetsTab);
        docsetFilterInput->setObjectName("docsetFilterInput");
        docsetFilterInput->setClearButtonEnabled(true);

        verticalLayout_2->addWidget(docsetFilterInput);

        availableDocsetList = new QListWidget(availableDocsetsTab);
        availableDocsetList->setObjectName("availableDocsetList");
        availableDocsetList->setSelectionMode(QAbstractItemView::ExtendedSelection);
        availableDocsetList->setSelectionBehavior(QAbstractItemView::SelectRows);
        availableDocsetList->setIconSize(QSize(16, 16));

        verticalLayout_2->addWidget(availableDocsetList);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lastUpdatedLabel = new QLabel(availableDocsetsTab);
        lastUpdatedLabel->setObjectName("lastUpdatedLabel");

        horizontalLayout->addWidget(lastUpdatedLabel);

        refreshButton = new QPushButton(availableDocsetsTab);
        refreshButton->setObjectName("refreshButton");

        horizontalLayout->addWidget(refreshButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        downloadDocsetsButton = new QPushButton(availableDocsetsTab);
        downloadDocsetsButton->setObjectName("downloadDocsetsButton");
        downloadDocsetsButton->setEnabled(false);

        horizontalLayout->addWidget(downloadDocsetsButton);


        verticalLayout_2->addLayout(horizontalLayout);

        label_4 = new QLabel(availableDocsetsTab);
        label_4->setObjectName("label_4");
        label_4->setTextFormat(Qt::RichText);
        label_4->setOpenExternalLinks(true);

        verticalLayout_2->addWidget(label_4);

        tabWidget->addTab(availableDocsetsTab, QString());

        verticalLayout->addWidget(tabWidget);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        statusLabel = new QLabel(Zeal__WidgetUi__DocsetsDialog);
        statusLabel->setObjectName("statusLabel");

        horizontalLayout_2->addWidget(statusLabel);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        storageStatusLabel = new QLabel(Zeal__WidgetUi__DocsetsDialog);
        storageStatusLabel->setObjectName("storageStatusLabel");

        horizontalLayout_2->addWidget(storageStatusLabel);

        buttonBox = new QDialogButtonBox(Zeal__WidgetUi__DocsetsDialog);
        buttonBox->setObjectName("buttonBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout_2->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(Zeal__WidgetUi__DocsetsDialog);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Zeal__WidgetUi__DocsetsDialog);
    } // setupUi

    void retranslateUi(QDialog *Zeal__WidgetUi__DocsetsDialog)
    {
        Zeal__WidgetUi__DocsetsDialog->setWindowTitle(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Docsets", nullptr));
        addFeedButton->setText(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Add feed", nullptr));
        updateSelectedDocsetsButton->setText(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Update", nullptr));
        updateAllDocsetsButton->setText(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Update all", nullptr));
        removeDocsetsButton->setText(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Remove", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(installedDocsetsTab), QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Installed", nullptr));
        docsetFilterInput->setPlaceholderText(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Filter docsets", nullptr));
        lastUpdatedLabel->setText(QString());
        refreshButton->setText(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Refresh", nullptr));
        downloadDocsetsButton->setText(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Download", nullptr));
        label_4->setText(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "<i>Docsets are provided by <a href=\"https://kapeli.com/dash\">Dash</a>.</i>", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(availableDocsetsTab), QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Available", nullptr));
        statusLabel->setText(QCoreApplication::translate("Zeal::WidgetUi::DocsetsDialog", "Downloading: 1. Installing: 5.", nullptr));
    } // retranslateUi

};

} // namespace WidgetUi
} // namespace Zeal

namespace Zeal {
namespace WidgetUi {
namespace Ui {
    class DocsetsDialog: public Ui_DocsetsDialog {};
} // namespace Ui
} // namespace WidgetUi
} // namespace Zeal

#endif // UI_DOCSETSDIALOG_H
